@@ -33,6 +33,7 @@
 #if defined(Q_OS_WIN32)
 #include <lmcons.h>
 #else
+#include <pwd.h>
 #include <unistd.h>
 #endif // #if defined(Q_OS_WIN32)
 
@@ -72,6 +73,7 @@
 #include "as_gfx/staterr.xpm"   // static const char *s_kpcStaterror_xpm[]
 #include "as_gfx/statwrn.xpm"   // static const char *s_kpcStatwarn_xpm[]
 #include "as_gfx/statvoid.xpm"  // static const char *s_kpcStatvoid_xpm[]
+#include "as_gfx/refresh.xpm"   // static const char *s_kpcRefresh_xpm[]
 
 
 //
@@ -79,7 +81,7 @@
 //
 void Titraqform::setupPrefs(void)
 {
-    QString Username;
+    QString Username, Homedir;
 
 // Start the show by getting the username
 #if defined(Q_OS_WIN32)
@@ -89,28 +91,41 @@ void Titraqform::setupPrefs(void)
         TCHAR szWinusername[UNLEN + 1];   // UNLEN is defined in lmcons.h
         GetUserName(szWinusername, &dwWinusernamesize);
         Username = qt_winQString(szWinusername);
-#else   // not unicode
+#else   // Not unicode
         char szWinusername[UNLEN + 1];    // UNLEN is defined in lmcons.h
         GetUserNameA(szWinusername, &dwWinusernamesize);
         Username = QString::fromLocal8Bit(szWinusername);
     }
 #endif  // #if defined(UNICODE)
-#else   // not windows
+#else   // Not windows
     {
 //#include <stdio.h>
 //        char *szUser = NULL;
 //        szUser = cuserid();
 //        Username = QString::fromLocal8Bit(szUser);
-        Username = QString::fromLocal8Bit(getlogin());
+        char *szLogin = getlogin();
+        passwd *pUserpwd = getpwnam(szLogin);
+
+        Homedir = QString::fromLocal8Bit(pUserpwd->pw_dir);
+        Username = QString::fromLocal8Bit(szLogin);
     }
 #endif  // #if defined(Q_OS_WIN32)
 
-    m_pPrefs = new Preferences(TITRAQ_PREFNAME, TITRAQ_APPTITLE, TITRAQ_PREFVER);
+    // Bootstrap a user preferences object from operating system info
+    m_pPrefs = new Preferences(Homedir + QChar('/') +
+                               QString::fromLocal8Bit(TITRAQ_PREFNAME),
+                               QString::fromLocal8Bit(TITRAQ_APPTITLE),
+                               QString::fromLocal8Bit(TITRAQ_PREFVER));
     if (!m_pPrefs->fileState()) {   // No file was found, so assume a null state
+        if (!Homedir.isEmpty())
+            m_pPrefs->setString(TITRAQ_PREFHOME, Homedir);
+        else
+            m_pPrefs->setString(TITRAQ_PREFHOME, TITRAQ_DEFUSER);
         if (!Username.isEmpty())
             m_pPrefs->setString(TITRAQ_PREFUSER, Username);
         else
             m_pPrefs->setString(TITRAQ_PREFUSER, TITRAQ_DEFUSER);
+        m_pPrefs->setString(TITRAQ_PREFACCOUNTS, TITRAQ_DEFACCOUNTS);
         m_pPrefs->setString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
         m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE);
         m_pPrefs->setString(TITRAQ_PREFVIEW, TITRAQ_DEFVIEW);
@@ -118,7 +133,8 @@ void Titraqform::setupPrefs(void)
         m_pPrefs->setString(TITRAQ_PREFLOCALLOG, TITRAQ_DEFLOCALLOG);
         m_pPrefs->flush();  // Write the new conf file
         QTextStream cerr(stderr, IO_WriteOnly);
-        cerr << trUtf8("Created new preferences file ") << trUtf8(TITRAQ_PREFNAME) << endl;
+        cerr << trUtf8("Created new preferences file ") << Homedir << QChar('/')
+             << QString::fromLocal8Bit(TITRAQ_PREFNAME) << endl;
     }
 
     // Use the preferred configuration values to initialize titraq
@@ -162,6 +178,7 @@ void Titraqform::setupActions(void)
     QMimeSourceFactory::defaultFactory()->setPixmap("paste", QPixmap(s_kpcPaste_xpm));
     QMimeSourceFactory::defaultFactory()->setPixmap("rowadd", QPixmap(s_kpcRowadd_xpm));
     QMimeSourceFactory::defaultFactory()->setPixmap("rowdel", QPixmap(s_kpcRowdel_xpm));
+    QMimeSourceFactory::defaultFactory()->setPixmap("refresh", QPixmap(s_kpcRefresh_xpm));
 
     // File new action
     m_pFilenewact = new QAction(trUtf8("New File"), QPixmap(s_kpcFilenew_xpm), trUtf8("&New..."), CTRL+Key_N, this, "New");
@@ -273,6 +290,17 @@ void Titraqform::setupActions(void)
                                    "You can also select the <b>Delete</b> command "
                                    "from the <b>Edit</b> menu.</p>";
     m_pDelrowact->setWhatsThis(kszDelrowtext);
+
+    // Refresh data display action
+    m_pRefreshact = new QAction(trUtf8("Refresh Display"), QPixmap(s_kpcRefresh_xpm), trUtf8("&Refresh display"), CTRL+Key_R, this, "Refresh");
+    if (m_pRefreshact == NULL)      // Sanity check
+        throw Genexcept("Main window refresh action creation failed.");
+    connect(m_pRefreshact, SIGNAL(activated()), this, SLOT(refreshDisplay()));
+    const char *kszRefreshtext = "<p><img source=\"refresh\"> "
+                                 "Click this button to <em>refresh the display</em>. "
+                                 "You can also select the <b>Refresh</b> command "
+                                 "from the <b>View</b> menu.</p>";
+    m_pRefreshact->setWhatsThis(kszRefreshtext);
 }
 
 //
@@ -342,6 +370,8 @@ void Titraqform::setupMenubar(void)
     nMenuid = m_pViewpopup->insertItem(trUtf8("&Timing"), this, SLOT(timingView()));
     m_pViewpopup->setItemEnabled(nMenuid, false);
     m_pViewpopup->insertSeparator();
+    m_pRefreshact->addTo(m_pViewpopup); // Refresh action
+    m_pViewpopup->insertSeparator();
     m_pViewpopup->insertItem(trUtf8("&Toolbars"), m_pTbarspopup);
     nMenuid = m_pTbarspopup->insertItem(trUtf8("&File"), this, SLOT(showFilebar()));
     m_pTbarspopup->setItemChecked(nMenuid, true);
@@ -424,6 +454,15 @@ void Titraqform::setupToolbars(void)
     m_pAddrowact->addTo(m_pEdittools);
     m_pDelrowact->addTo(m_pEdittools);
 
+    // Construct and populate the view tool bar
+    m_pViewtools = new QToolBar("Toolview", this, DockTop);
+    if (m_pViewtools == NULL)                   // Sanity check
+        throw Genexcept("View tool bar creation failed.");
+    m_pViewtools->setLabel(trUtf8("View Ops"));
+    m_pViewtools->setOpaqueMoving(false);
+    m_pViewtools->setCloseMode(QDockWindow::Never);
+    m_pRefreshact->addTo(m_pViewtools);
+
     // Construct and populate the lonely whatsthis tool bar
     m_pWhatstools = new QToolBar("Toolwhats", this, DockTop);
     if (m_pWhatstools == NULL)                  // Sanity check
@@ -535,6 +574,7 @@ void Titraqform::setupTable(void)
     connect(m_pMaintable, SIGNAL(doubleClicked(int, int, int, const QPoint&)), this, SLOT(inplaceEdit(int, int, int, const QPoint&)));
     connect(m_pTablehead, SIGNAL(sizeChange(int, int, int)), this, SLOT(updSizes(int, int, int)));
     connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(dataChanged(void)));
+    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(validateData(int, int)));
     connect(m_pMaintable, SIGNAL(textEdited(void)), this, SLOT(dataChanged(void)));
 }
 
@@ -736,16 +776,9 @@ void Titraqform::setupEditlay(void)
     if (m_pTaskentries == NULL) // Sanity check
         throw Genexcept("Main window task entries creation failed.");
 
-    // Populate the stringlist with fresh tasks
-    *m_pTaskentries << trUtf8("titraq")         << trUtf8("opgui")
-                    << trUtf8("email")          << trUtf8("admin")
-                    << trUtf8("pmod")           << trUtf8("psod")
-                    << trUtf8("brainstorming")  << trUtf8("communication")
-                    << trUtf8("evaluation")     << trUtf8("holiday")
-                    << trUtf8("implementation") << trUtf8("maintainance")
-                    << trUtf8("prepare")        << trUtf8("perform")
-                    << trUtf8("visit")          << trUtf8("meeting")
-                    << trUtf8("troubleshooting") << trUtf8("weekly");
+    // Populate the stringlist with fresh accounts, taken from filename in prefs
+    QFile Filetemp(m_pPrefs->getString(TITRAQ_PREFACCOUNTS, TITRAQ_PREFACCOUNTS));
+    this->loadAccounts(Filetemp);           // Load account helper method
 
     // Make the combobox task edit
     m_pTasks = new QComboBox(true, m_pCenframe, "Tasks");
@@ -844,6 +877,10 @@ void Titraqform::setupColumns(void)
         m_pEdittools->hide();
         m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXEDITBAR), false);
     }
+    if (!m_pPrefs->getBool(TITRAQ_PREFVIEWBAR, TITRAQ_DEFVIEWBAR)) {
+        m_pViewtools->hide();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXVIEWBAR), false);
+    }
     if (!m_pPrefs->getBool(TITRAQ_PREFWHATBAR, TITRAQ_DEFWHATBAR)) {
         m_pWhatstools->hide();
         m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXWHATBAR), false);
