@@ -45,7 +45,73 @@
 #include <iostream>
 
 //
-// Convenience method to load accounting data from a file
+// Convenience method to load accounts from a file
+//
+void Titraqform::loadAccounts(QFile &Fileobj)
+{
+    if (Fileobj.isOpen()) {             // Check state of file
+        Fileobj.flush();                // Begin processing file cleanly
+        QTextStream Account(&Fileobj);  // Convert data to stream
+        this->loadAccounts(Account);    // Pass off to do the real work
+    }
+    else {
+        if (!Fileobj.open(IO_ReadOnly)) // Try to open file
+            throw Genexcept("Could not open account file.");
+        else
+            Fileobj.flush();                // Begin processing file cleanly
+            QTextStream Account(&Fileobj);  // Convert data to stream
+            this->loadAccounts(Account);    // Pass off to do the real work
+            Fileobj.close();                // Finish fileop by closing
+    }
+}
+
+//
+// Load accounts themselves data from a stream
+//
+void Titraqform::loadAccounts(QTextStream &Tstream)
+{
+    QString Line; // Used for linewise editing and whitespace eating
+
+    // Eat lines until reading the start accounts token
+    while (!Line.startsWith(trUtf8("%!AS-ACCOUNTS")) && !Tstream.atEnd()) {
+        Line = trUtf8(""); // Empty line for later inspection
+        Line = Tstream.readLine(); // Get a new line to examine
+    }
+
+    // Strip out extra line feeds in stream
+    while (Line.isEmpty() && !Tstream.atEnd()) {
+        Tstream.skipWhiteSpace();       // Strip and get
+        Line = Tstream.readLine();      // the new line
+        if (Line.at(0) == QChar('#'))   // Remove comments
+            Line = trUtf8("");
+    }
+
+    // Set the accounts choices by linewise reading from the input
+    // stream and parsing the corresponding account fields out of it
+    while (!Line.isEmpty()) {
+        QString Temp;                           // For reading from stream
+        QTextStream Asline(&Line, IO_ReadOnly); // Convert a single line
+
+        Asline.skipWhiteSpace();            // Remove whitespaces
+        Asline >> Temp;                     // Copy revision indicator
+
+        if (Temp == QString(QChar('R'))) {  // Copy the account field
+            Asline >> Temp;                 // to temporary for transfer
+            *m_pTaskentries << Temp;        // to internal account bank
+        }
+
+        Line = trUtf8(""); // Clear line for next round
+        while (Line.isEmpty() && !Tstream.atEnd()) {
+            Tstream.skipWhiteSpace();       // Strip and get
+            Line = Tstream.readLine();      // the new line
+            if (Line.at(0) == QChar('#'))   // Remove comments
+                Line = trUtf8("");
+        }
+    }
+}
+
+//
+// Convenience method to load personal data from a file
 //
 void Titraqform::loadData(QFile &Fileobj)
 {
@@ -56,15 +122,17 @@ void Titraqform::loadData(QFile &Fileobj)
     }
     else {
         if (!Fileobj.open(IO_ReadOnly)) // Try to open file
-            throw Genexcept("Could not read open accounting file.");
-        QTextStream Asentry(&Fileobj);  // Convert data to stream
-        this->loadData(Asentry);        // Pass off to do the real work
-        Fileobj.close();                // Finish fileop by closing
+            throw Genexcept("Could not open personal data file.");
+        else
+            Fileobj.flush();                // Begin processing file cleanly
+            QTextStream Asentry(&Fileobj);  // Convert data to stream
+            this->loadData(Asentry);        // Pass off to do the real work
+            Fileobj.close();                // Finish fileop by closing
     }
 }
 
 //
-// Load accounting data from a stream
+// Load personal data from a stream
 //
 void Titraqform::loadData(QTextStream &Tstream)
 {
@@ -78,8 +146,12 @@ void Titraqform::loadData(QTextStream &Tstream)
     QPixmap Staterror(s_kpcStaterror_xpm);
 
     // Strip out extra line feeds at stream start
-    while (Line.isEmpty() && !Tstream.atEnd())
-        Line = Tstream.readLine();
+    while (Line.isEmpty() && !Tstream.atEnd()) {
+        Tstream.skipWhiteSpace();       // Strip and get
+        Line = Tstream.readLine();      // the new line
+        if (Line.at(0) == QChar('#'))   // Remove comments
+            Line = trUtf8("");
+    }
 
     // Optimize viewing by repainting cells only once after processing
     m_pMaintable->setUpdatesEnabled(false);
@@ -295,8 +367,16 @@ const QString Titraqform::getRowdata(void) const
     // Calculate rows to delete from selection highlight
     for (int nIter = 0; nIter < nTotal; ++nIter) {
         // Build the row data string one field at a time, adding seps inbetween
+        Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXLINE);
+        Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
         Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXUSER);
         Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
+        Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXGUID);
+        Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
+        Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXCRC);
+        Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
+        Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXREV);
+        Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
         Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXDATE);
         Rowdata += trUtf8(TITRAQ_SEPARATORTOK);
         Rowdata += m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXSTART);
@@ -322,17 +402,21 @@ void Titraqform::setRowdata(QString &Rowdata) const
     int nRows = Rowdata.contains(QChar('\n'));          // Set so many rows
     int nCurrentrow = m_pMaintable->currentRow();       // Current table row
     QTableItem *pItem = NULL;                           // Old item to change out
-    QString User;                                       // Admin fields in table
+    QString Line, User, Guid, Crc, Rev;                 // Admin fields in table
     QString Date, Start, Finish, Amount, Task, Remark;  // Viewable fields in table
     QTextStream Datastream(&Rowdata, IO_ReadOnly);      // Convert data to stream
 
     for (int nIter = 0; nIter < nRows; ++nIter) {
-        Datastream >> User >> Date >> Start;            // Stream data fields
-        Datastream >> Finish >> Amount >> Task;         // to corresponding vars
-        Remark = Datastream.readLine();                 // Remark is a whole line
+        Datastream >> Line >> User >> Guid >> Crc >> Rev;        // Stream data fields
+        Datastream >> Date >> Start >> Finish >> Amount >> Task; // to corresponding vars
+        Remark = Datastream.readLine();                          // Remark is a whole line
 
         // Set the table row data one field at a time, skipping seps inbetween
+        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXLINE, Line);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXUSER, User);
+        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXGUID, Guid);
+        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXCRC, Crc);
+        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXREV, Rev);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXDATE, Date);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXSTART, Start);
         m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXFINISH, Finish);
@@ -350,8 +434,7 @@ void Titraqform::setRowdata(QString &Rowdata) const
         m_pMaintable->setItem(nCurrentrow + nIter, TITRAQ_IDXTASK, new RtTableItem(m_pMaintable, QTableItem::WhenCurrent, Task));
 
         // Continue with field processing business as usual
-        Remark.simplifyWhiteSpace(); // First get rid of and simplify whitespace
-        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXREMARK, Remark);
+        m_pMaintable->setText(nCurrentrow + nIter, TITRAQ_IDXREMARK, Remark.simplifyWhiteSpace());
     }
 }
 
