@@ -92,6 +92,12 @@ void Titraqform::pasteEntry(void)
         nRows = Selection.contains(QChar('\n'));    // How many rows
         this->addEntry(nRows);                      // Reuse slot
         setRowdata(Selection);                      // Use accessor
+
+        // Update line numbers for this new row and all subsequent rows
+        for (int nIter = m_pMaintable->currentRow(); nIter < m_pMaintable->numRows(); nIter++)
+            m_pMaintable->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter).rightJustify(4, QChar('0')));
+
+        // Do basic data validation to warn against missing fields
         for (int nIter = 0; nIter <= nRows; nIter++)
             this->validateData(m_pMaintable->currentRow() + nIter, 0);
     }
@@ -205,6 +211,25 @@ void Titraqform::delEntry(int nRows)
         m_pMaintable->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter));
 }
 
+//
+// Refresh the display of all data items
+//
+void Titraqform::refreshDisplay(void)
+{
+    int nIter = 0;                          // Matrix iterator
+    int nRows = m_pMaintable->numRows();    // Total number of rows
+
+    // Sweep through matrix validating linewise
+    // data and updating line numbers for all rows
+    while (nIter < nRows) {
+        this->validateData(nIter, 0);
+        m_pMaintable->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter).rightJustify(4, QChar('0')));
+        nIter++;
+    }
+
+    this->repaint(); // Do a general repaint of viewable area
+}
+
 //
 // Make and display a new document window
 //
@@ -887,6 +912,21 @@ void Titraqform::showEditbar(void)
     }
 }
 
+//
+// View menu show view toolbar
+//
+void Titraqform::showViewbar(void)
+{
+    if (m_pViewtools->isVisible()) {
+        m_pViewtools->hide();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXVIEWBAR), false);
+    }
+    else {
+        m_pViewtools->show();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXVIEWBAR), true);
+    }
+}
+
 //
 // View menu show whats this toolbar
 //
