@@ -44,10 +44,16 @@ bool TiTable::eventFilter(QObject *pObject, QEvent *pEvent)
         ((QMouseEvent *)pEvent)->button() == QMouseEvent::MidButton)
         return true;
     else if (pEvent->type() == QEvent::KeyPress) {
-        if (((QKeyEvent *)pEvent)->key() == Qt::Key_Tab) {          // Handle tab key
+        if (((QKeyEvent *)pEvent)->key() == Qt::Key_Tab) { // Handle tab key
             if (this->getEdition() >= 0) {
-                int nColadvance = ((currentColumn() + 1) % TITRAQ_IDXTAIL);
-                if (nColadvance == 0)   // Advance the column and possibly the row too
+                int nIter = 1; // Logic to skip invisible or read only columns
+                while (columnWidth((currentColumn() + nIter) % TITRAQ_IDXTAIL) <= 0
+                    || isColumnReadOnly((currentColumn() + nIter) % TITRAQ_IDXTAIL))
+                    nIter++;
+
+                // Advance the column or both row and column possibly
+                int nColadvance = ((currentColumn() + nIter) % TITRAQ_IDXTAIL);
+                if ((currentColumn() + nIter) >= TITRAQ_IDXTAIL)
                     this->setCurrentCell(currentRow() + 1, nColadvance);
                 else
                     this->setCurrentCell(currentRow(), nColadvance);
@@ -56,15 +62,39 @@ bool TiTable::eventFilter(QObject *pObject, QEvent *pEvent)
                 this->setEdition(currentColumn());
                 this->setReadOnly(true);
             }
-            return true;    // Handled the tab key event and cancel its progress
+            return true; // Handle the tab key event and cancel its progress
         }
+        else if (((QKeyEvent *)pEvent)->key() == Qt::Key_Backtab) { // Handle shift tab key
+            if (this->getEdition() >= 0) {
+                int nIter = 1; // Logic to skip invisible or read only columns
+                while (columnWidth((currentColumn() - nIter + TITRAQ_IDXTAIL) % TITRAQ_IDXTAIL) <= 0
+                    || isColumnReadOnly((currentColumn() - nIter + TITRAQ_IDXTAIL) % TITRAQ_IDXTAIL))
+                    nIter++;
+
+                // Advance the column or both row and column possibly
+                int nColadvance = (currentColumn() - nIter + TITRAQ_IDXTAIL) % TITRAQ_IDXTAIL;
+                if ((currentColumn() - nIter) < 0)
+                    this->setCurrentCell(currentRow() - 1, nColadvance);
+                else
+                    this->setCurrentCell(currentRow(), nColadvance);
+                this->setReadOnly(false);
+                this->editCell(currentRow(), currentColumn());
+                this->setEdition(currentColumn());
+                this->setReadOnly(true);
+            }
+            return true; // Handle the shift tab key event and cancel its progress
+        }
+        else if (((QKeyEvent *)pEvent)->key() == Qt::Key_Up && this->getEdition() >= 0) // Handle up key
+            return true;                                            // Capture
+        else if (((QKeyEvent *)pEvent)->key() == Qt::Key_Down && this->getEdition() >= 0) // Handle down key
+            return true;                                            // Capture
         else if (((QKeyEvent *)pEvent)->key() == Qt::Key_Escape)    // Handle escape key
             this->setEdition();
 
         // Forward incompletely handled key events
         return QTable::eventFilter(pObject, pEvent);
     }
-    else                    // Default behaviour is to pass the event onwards
+    else // Default behaviour is to pass the event onwards
         return QTable::eventFilter(pObject, pEvent);
 }
 
